# Topsis-Snehil-101903064

Topsis implementation in python. Used as a command line tool to generate topsis score and ranks of the given input data file along with weights and impacts.

## Installation

`pip install Topsis-Snehil-101903064`

## How to use it?

Open the terminal / cmd and type topsis <input_filename.csv> <"Weights"> <"Impacts"> <output_filename.csv>

## License

© 2022 Snehil Gupta

This repository is licensed under the MIT license. See LICENSE for details.
